SetWeatherStation — pywws 13.06_r1023 documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »

# SetWeatherStation

Régle certains paramètres de la station météo.

    usage: python -m pywws.SetWeatherStation [options]
    options are:
     -h   | --help           display this help
     -c   | --clock          set weather station clock to computer time
                             (unlikely to work)
     -p f | --pressure f     set relative pressure to f hPa
     -r n | --read_period n  set logging interval to n minutes
     -v   | --verbose        increase error message verbosity
     -z   | --zero_memory    clear the weather station logged reading count

Fonctions

`bcd_encode`(value) |
`main`([argv]) |

`pywws.SetWeatherStation.` `bcd_encode`(value)

`pywws.SetWeatherStation.` `main`(argv=None)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.06_r1023 documentation »
- Programmes et des modules Python »